@@ -1,9 +1,9 @@
-import Button.py
-import questions.py
+import PythonPals.Button
+import PythonPals.questions
 import pygame
 import pygame.gfxdraw
 import textwrap
-from player.py import Player, Coffee, Ruby, Eye
+from PythonPals.player import Player, Coffee, Ruby, Eye
 
 class Screen():
     def __init__(self, width, height):
